@@ -111,6 +111,8 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
     m_inflectionWidget->setDocument(doc);
     m_comparisonWidget->setDocument(doc);
     m_synonymWidget->setDocument(doc);
+    m_antonymWidget->setDocument(doc);
+    m_falseFriendWidget->setDocument(doc);
 
     if (!m_mainWindow->parleyDocument()->document()) {
         return;
@@ -161,9 +163,9 @@ void EditorWindow::initDockWidgets()
 
     m_lessonModel = new LessonModel(this);
     m_lessonView->setModel(m_lessonModel);
-    m_lessonView->setToolTip(i18n("Right click to add, delete, or rename lessons. \n"
-                                  "With the checkboxes you can select which lessons you want to practice. \n"
-                                  "Only checked lessons [x] will be asked in the tests!"));
+    m_lessonView->setToolTip(i18n("Right click to add, delete, or rename units. \n"
+                                  "With the checkboxes you can select which units you want to practice. \n"
+                                  "Only checked units [x] will be asked in the practice!"));
 
     connect(m_lessonView, SIGNAL(selectedLessonChanged(KEduVocLesson*)),
             m_vocabularyModel, SLOT(setLesson(KEduVocLesson*)));
@@ -219,7 +221,7 @@ void EditorWindow::initDockWidgets()
     QScrollArea *comparisonScrollArea = new QScrollArea(this);
     comparisonScrollArea->setWidgetResizable(true);
     comparisonScrollArea->setWidget(m_comparisonWidget);
-    inflectionDock->setWidget(comparisonScrollArea);
+    comparisonDock->setWidget(comparisonScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, comparisonDock);
     m_dockWidgets.append(comparisonDock);
     actionCollection()->addAction("show_comparison_dock", comparisonDock->toggleViewAction());
@@ -260,32 +262,32 @@ void EditorWindow::initDockWidgets()
 
     QDockWidget *antonymDock = new QDockWidget(i18n("Antonyms"), this);
     antonymDock->setObjectName("AntonymDock");
-    SynonymWidget *antonymWidget = new SynonymWidget(SynonymWidget::Antonym, this);
+    m_antonymWidget = new SynonymWidget(SynonymWidget::Antonym, this);
     QScrollArea *antonymScrollArea = new QScrollArea(this);
     antonymScrollArea->setWidgetResizable(true);
-    antonymScrollArea->setWidget(antonymWidget);
+    antonymScrollArea->setWidget(m_antonymWidget);
     antonymDock->setWidget(antonymScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, antonymDock);
     m_dockWidgets.append(antonymDock);
     actionCollection()->addAction("show_antonym_dock", antonymDock->toggleViewAction());
     antonymDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-            antonymWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            m_antonymWidget, SLOT(setTranslation(KEduVocExpression*, int)));
     tabifyDockWidget(synonymDock,antonymDock);
 
     QDockWidget *falseFriendDock = new QDockWidget(i18n("False Friends"), this);
     falseFriendDock->setObjectName("FalseFriendDock");
-    SynonymWidget *falseFriendWidget = new SynonymWidget(SynonymWidget::FalseFriend, this);
+    m_falseFriendWidget = new SynonymWidget(SynonymWidget::FalseFriend, this);
     QScrollArea *falseFriendScrollArea = new QScrollArea(this);
     falseFriendScrollArea->setWidgetResizable(true);
-    falseFriendScrollArea->setWidget(falseFriendWidget);
+    falseFriendScrollArea->setWidget(m_falseFriendWidget);
     falseFriendDock->setWidget(falseFriendScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, falseFriendDock);
     m_dockWidgets.append(falseFriendDock);
     actionCollection()->addAction("show_falsefriend_dock", falseFriendDock->toggleViewAction());
     falseFriendDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-            falseFriendWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            m_falseFriendWidget, SLOT(setTranslation(KEduVocExpression*, int)));
     tabifyDockWidget(antonymDock,falseFriendDock);
 
 // Pronunciation symbols - Use KCharSelect
