@@ -31,7 +31,6 @@
 #include "settings/parleyprefs.h"
 #include "configure-practice/configurepracticedialog.h"
 #include "practice/guifrontend.h"
-#include "practice/practiceoptions.h"
 #include "practice/practicesummarycomponent.h"
 
 #include "parleyactions.h"
@@ -62,7 +61,7 @@ ParleyMainWindow::ParleyMainWindow(const KUrl& filename)
     : KXmlGuiWindow(0)
     , m_currentComponent(NoComponent)
     , m_currentComponentWindow(0)
-    , m_testEntryManager(this)
+    , m_sessionManager(this)
 {
     s_instance = this;
     m_document = new ParleyDocument(this);
@@ -119,6 +118,12 @@ void ParleyMainWindow::addRecentFile(const KUrl &url, const QString &name)
     m_recentFilesAction->saveEntries(KGlobal::config()->group("Recent Files"));
 }
 
+void ParleyMainWindow::removeRecentFile(const KUrl &url)
+{
+    m_recentFilesAction->removeUrl(url);
+    m_recentFilesAction->saveEntries(KGlobal::config()->group("Recent Files"));
+}
+
 void ParleyMainWindow::updateRecentFilesModel()
 {
     emit recentFilesChanged();
@@ -172,6 +177,13 @@ void ParleyMainWindow::configurePractice()
 
 void ParleyMainWindow::startPractice()
 {
+    if (Prefs::learningLanguage() == Prefs::knownLanguage()) {
+        KMessageBox::sorry(this,
+                           i18n("You cannot start to practice when the known language is the same as the language to learn."),
+                           i18n("Select languages"));
+        return;
+    }
+
     switchComponent(PracticeComponent);
 }
 
@@ -182,38 +194,7 @@ void ParleyMainWindow::practiceFinished()
 
 bool ParleyMainWindow::queryClose()
 {
-    bool erg = queryExit();
-    if (erg && m_document->document()) {
-        m_document->document()->setModified(false);  // avoid double query on exit via system menu
-    }
-    return erg;
-}
-
-bool ParleyMainWindow::queryExit()
-{
-    if (!m_document->document() || !m_document->document()->isModified()) {
-        return true;
-    }
-    saveOptions();
-
-    bool save = Prefs::autoSave(); //save without asking
-
-    if (!save) {
-        int exit = KMessageBox::warningYesNoCancel(this, i18n("Vocabulary is modified.\n\nSave file before exit?\n"),
-                   "", KStandardGuiItem::save(), KStandardGuiItem::discard());
-        if (exit == KMessageBox::Yes) {
-            save = true;   // save and exit
-        } else if (exit == KMessageBox::No) {
-            save = false;  // don't save but exit
-        } else {
-            return false;  // continue work
-        }
-    }
-
-    if (save) {
-        m_document->save();       // save and exit
-    }
-    return true;
+    return m_document->queryClose();
 }
 
 QSize ParleyMainWindow::sizeHint() const
@@ -294,8 +275,8 @@ void ParleyMainWindow::switchComponent(Component component)
 
         // Don't start a practice when there are no words to practice.
         // This has to be checked before deleting the old component.
-        m_testEntryManager.setDocument(m_document->document());
-        if (!m_testEntryManager.totalEntryCount()) {
+        m_sessionManager.setDocument(m_document->document());
+        if (!m_sessionManager.allEntryCount()) {
             return;
         }
     }
@@ -304,7 +285,7 @@ void ParleyMainWindow::switchComponent(Component component)
     if (m_currentComponentWindow) {
         guiFactory()->removeClient(m_currentComponentWindow);
         centralWidget()->layout()->removeWidget(m_currentComponentWindow);
-        delete(m_currentComponentWindow);
+        m_currentComponentWindow->deleteLater();
     }
 
     switch (component) {
@@ -312,7 +293,7 @@ void ParleyMainWindow::switchComponent(Component component)
         WelcomeScreen *welcome = new WelcomeScreen(this);
         m_currentComponentWindow = welcome;
         showDocumentActions(true, false);
-        welcome->updateRecentFilesModel();
+        //welcome->updateRecentFilesModel();
         break;
     }
     case ConfigurePracticeComponent: {
@@ -330,7 +311,7 @@ void ParleyMainWindow::switchComponent(Component component)
     }
     case PracticeComponent: {
         m_document->document()->setModified(true);
-        Practice::PracticeMainWindow *practiceWindow = new Practice::PracticeMainWindow(&m_testEntryManager, this);
+        Practice::PracticeMainWindow *practiceWindow = new Practice::PracticeMainWindow(&m_sessionManager, this);
         connect(practiceWindow, SIGNAL(stopPractice()), this, SLOT(showPracticeSummary()));
         m_currentComponentWindow = practiceWindow;
         showDocumentActions(false, false);
@@ -338,7 +319,7 @@ void ParleyMainWindow::switchComponent(Component component)
         break;
     }
     case PracticeSummary: {
-        Practice::PracticeSummaryComponent* summary = new Practice::PracticeSummaryComponent(&m_testEntryManager, this);
+        Practice::PracticeSummaryComponent* summary = new Practice::PracticeSummaryComponent(&m_sessionManager, this);
         m_currentComponentWindow = summary;
         showDocumentActions(true, true);
         break;
