@@ -29,7 +29,8 @@
 #include "parleydocument.h"
 
 #include <KXmlGuiWindow>
-#include "practice/testentrymanager.h"
+#include "practice/sessionmanagercontinuous.h"
+#include "practice/sessionmanagerfixed.h"
 
 #include <QPointer>
 
@@ -117,8 +118,9 @@ public slots:
 
     /** When quitting, ask for confirmation if the doc has not been saved */
     bool queryClose();
-    /** overloaded for Message box on last window exit */
-    bool queryExit();
+
+    /** remove an entry from the list of recent files */
+    void removeRecentFile(const KUrl &url);
 
     QSize sizeHint() const;
 
@@ -164,30 +166,22 @@ signals:
     void preferencesChanged();
 
 private:
-    ParleyMainWindow(const KUrl& filename = KUrl());
+    ParleyMainWindow(const KUrl &filename = KUrl());
     static ParleyMainWindow *s_instance;
 
-    Component m_currentComponent;
+    Component      m_currentComponent;
+    KXmlGuiWindow *m_currentComponentWindow;
 
-    /*
-    WelcomeScreen *m_welcomeScreen;
-    Editor::EditorWindow *m_editor;
-    Practice::GuiFrontend *m_practiceFrontend;
-    Practice::DefaultBackend *m_practiceBackend;
-    StatisticsMainWindow *m_statisticsWidget;
-    Practice::PracticeSummaryComponent *m_practiceSummary;
-    */
-    KXmlGuiWindow* m_currentComponentWindow;
-
-    KRecentFilesAction* m_recentFilesAction;
+    KRecentFilesAction *m_recentFilesAction;
 
     /** m_document is the current vocabulary document. */
     ParleyDocument   *m_document;
 
-    /// the name of the executable
-    QString m_appName;
     Component m_componentBeforePractice;
-    Practice::TestEntryManager m_testEntryManager;
+
+
+    //Practice::SessionManagerContinuous m_sessionManager;
+    Practice::SessionManagerFixed        m_sessionManager;
 
     friend int main(int argc, char* argv[]);
 };
