@@ -29,13 +29,12 @@
 
 #include "parleymainwindow.h"
 #include "guifrontend.h"
-#include "practiceoptions.h"
 #include "practicestatemachine.h"
 #include <languagesettings.h>
 
 using namespace Practice;
 
-PracticeMainWindow::PracticeMainWindow(TestEntryManager* testEntryManager,
+PracticeMainWindow::PracticeMainWindow(SessionManagerBase* sessionManager,
                                        ParleyMainWindow* mainWindow)
     : KXmlGuiWindow(mainWindow), m_mainWindow(mainWindow)
 {
@@ -46,8 +45,7 @@ PracticeMainWindow::PracticeMainWindow(TestEntryManager* testEntryManager,
     m_guiFrontend = new GuiFrontend(this);
     setCentralWidget(m_guiFrontend->widget());
 
-    PracticeOptions options;
-    m_stateMachine = new PracticeStateMachine(m_guiFrontend, mainWindow->parleyDocument(), options, testEntryManager, this);
+    m_stateMachine = new PracticeStateMachine(m_guiFrontend, mainWindow->parleyDocument(), sessionManager, this);
 
     // setModified - otherwise we may not ask to save progress
     mainWindow->parleyDocument()->document()->setModified(true);
@@ -63,8 +61,11 @@ PracticeMainWindow::PracticeMainWindow(TestEntryManager* testEntryManager,
 
 PracticeMainWindow::~PracticeMainWindow()
 {
+    //m_floatingToolBar is a child of m_mainWindow will be deleted with its children
+    //before or after this.  So don't access it in toggleFullScreenMode.
+    m_floatingToolBar = 0;
     toggleFullScreenMode(false);
-    delete m_floatingToolBar;
+
     KConfigGroup cfg(KSharedConfig::openConfig("parleyrc"), objectName());
     saveMainWindowSettings(cfg);
 }
@@ -90,6 +91,7 @@ void PracticeMainWindow::initActions()
     toggleAnswerState->setShortcut(Qt::CTRL + Qt::Key_Space);
     connect(toggleAnswerState, SIGNAL(triggered()), m_guiFrontend, SLOT(toggleResultState()));
 
+    //m_floatingToolBar now a child of m_mainWindow and will be deleted with its parent
     m_floatingToolBar = new QWidget(m_mainWindow);
     QHBoxLayout *layout = new QHBoxLayout();
     m_floatingToolBar->setLayout(layout);
@@ -143,30 +145,35 @@ void PracticeMainWindow::toggleFullScreenMode(bool fullScreen)
     KToggleFullScreenAction::setFullScreen(m_mainWindow, fullScreen);
     m_mainWindow->toolBar("practiceToolBar")->setVisible(!fullScreen);
     m_mainWindow->menuBar()->setVisible(!fullScreen);
-    m_floatingToolBar->setVisible(fullScreen);
+    if ( m_floatingToolBar != 0 ) {
+        m_floatingToolBar->setVisible(fullScreen);
+    }
     m_mainWindow->setSettingsDirty();
 }
 
 void PracticeMainWindow::startPractice()
 {
-    QString questionLocale = m_mainWindow->parleyDocument()->document()->identifier(Prefs::questionLanguage()).locale();
-    LanguageSettings questionLanguageSettings(questionLocale);
-    questionLanguageSettings.readConfig();
-    QFont questionFont = questionLanguageSettings.practiceFont();
-    m_guiFrontend->setQuestionFont(questionFont);
+    // Set the fonts for the known language and learning language.
+    // These are used in the practice state machine to set the
+    // questionfont and answerfont in the mode widget.
+    QString knownLangLocale = m_mainWindow->parleyDocument()->document()->identifier(Prefs::knownLanguage()).locale();
+    LanguageSettings knownLangSettings(knownLangLocale);
+    knownLangSettings.readConfig();
+    QFont knownLangFont = knownLangSettings.practiceFont();
+    m_guiFrontend->setKnownLangFont(knownLangFont);
 
-    QString solutionLocale = m_mainWindow->parleyDocument()->document()->identifier(Prefs::solutionLanguage()).locale();
-    LanguageSettings solutionLanguageSettings(solutionLocale);
-    solutionLanguageSettings.readConfig();
-    QFont solutionFont = solutionLanguageSettings.practiceFont();
-    m_guiFrontend->setSolutionFont(solutionFont);
+    QString learningLangLocale = m_mainWindow->parleyDocument()->document()->identifier(Prefs::learningLanguage()).locale();
+    LanguageSettings learningLangSettings(learningLangLocale);
+    learningLangSettings.readConfig();
+    QFont learningLangFont = learningLangSettings.practiceFont();
+    m_guiFrontend->setLearningLangFont(learningLangFont);
 
     m_stateMachine->start();
 }
 
 void PracticeMainWindow::practiceFinished()
 {
-    kDebug() << "finished";
+    m_guiFrontend->modeWidgetDestroyed(0);
     delete m_stateMachine;
     emit stopPractice();
 }
