@@ -39,6 +39,35 @@ WrittenPracticeWidget::WrittenPracticeWidget(GuiFrontend *frontend, QWidget *par
     connect(frontend, SIGNAL(skipAction()), this, SIGNAL(stopAudio()));
 }
 
+void WrittenPracticeWidget::objectDestroyed(QObject *) {
+    /**
+      @page bug332596 bug 332596 Deleting a qstyled KLineEdit causes crash
+
+     The bug was as follows.  When a WrittenPracticeWidget using a KLineEdit
+     styled with a qStyleSheet that has focus is deleted this triggers a focus
+     changing event, but the QStyleSheet returns a style that has already been
+     deleted and causes a crash when the invalid style is applied.
+
+     The obvious solution of responding to the destroyed() event doesn't work
+     , because the destroyed() event happens after the crash.
+
+     In order to fix this bug, I transistion focus away from the KLineEdit before
+     the focus change preceding deletion.  The virtual function,
+     WrittenPracticeWidget::objectDestroyed,  avoids having a
+     practice mode switch statement as large as this comment at each delete event.
+
+     Transitioning to helpLabel was chosen arbitrarily.
+
+     @todo When frameworks/kde5 is implemented remove this code
+     , if the bug in Qt (returning a pointer to a deleted stylesheet) is fixed.
+     If this function is removed then the entire inheritance path can be removed.
+     */
+
+    m_ui->helpLabel->setFocus();
+    delete m_ui;
+    m_ui = 0;
+}
+
 
 void WrittenPracticeWidget::setQuestionFont(const QFont& font)
 {
